SyncStatefulChat

Struct SyncStatefulChat 

pub struct SyncStatefulChat { /* private fields */ }
Blocking wrapper for stateful chat interactions.

Implementations

Source

impl SyncStatefulChat

pub fn append( &mut self, role: Role, content: impl Into<MessageContent>, ) -> &mut Self

Append a message to local state.

pub fn append_system(&mut self, content: impl Into<String>) -> &mut Self

Append a system message.

pub fn append_user(&mut self, content: impl Into<MessageContent>) -> &mut Self

Append a user message.

pub fn append_assistant(&mut self, content: impl Into<String>) -> &mut Self

Append an assistant message.

pub fn append_tool_result( &mut self, tool_call_id: impl Into<String>, content: impl Into<String>, ) -> &mut Self

Append a tool result message.

pub fn append_message(&mut self, message: Message) -> &mut Self

Append a pre-built message.

pub fn messages(&self) -> &[Message]

Get local message history.

pub fn pending_tool_calls(&self) -> &[ToolCall]

Get pending tool calls from the latest sampled response.

pub fn take_pending_tool_calls(&mut self) -> Vec<ToolCall>

Take and clear pending tool calls.

pub fn clear(&mut self) -> &mut Self

Clear local chat state.

pub fn sample(&self) -> Result<Response>

Sample with current local message history.

pub fn append_response_text(&mut self, response: &Response) -> &mut Self

Append assistant text from a sampled response.

pub fn append_response_semantics(&mut self, response: &Response) -> &mut Self

Append response semantics and pending tool calls to local state.

pub fn sample_and_append(&mut self) -> Result<Response>

Sample and append response semantics.

pub fn sample_with_tool_loop<H>(&mut self, handler: H) -> Result<Response>
where H: FnMut(ToolCall) -> Result<String>,

Run a blocking tool loop with default max rounds.

pub fn sample_with_tool_handler<H>( &mut self, max_rounds: u32, handler: H, ) -> Result<Response>
where H: FnMut(ToolCall) -> Result<String>,

Run a blocking tool loop with explicit max rounds.